@@ -1,9 +1,9 @@
+use crate::contexts::Contexts;
 use crate::steps::Step;
 use crate::{actions::Action, manifests::Manifest};
 use serde::{Deserialize, Serialize};
-use tera::Context;
 
-#[derive(Clone, Debug, PartialEq, Serialize, Deserialize)]
+#[derive(Clone, Debug, Default, PartialEq, Serialize, Deserialize)]
 pub struct RunCommand {
     pub command: String,
 
@@ -13,15 +13,24 @@ pub struct RunCommand {
     #[serde(default = "get_false")]
     pub sudo: bool,
 
-    pub dir: Option<String>,
+    #[serde(default = "get_cwd")]
+    pub dir: String,
 }
 
 fn get_false() -> bool {
     false
 }
 
+fn get_cwd() -> String {
+    std::env::current_dir()
+        .unwrap()
+        .into_os_string()
+        .into_string()
+        .unwrap()
+}
+
 impl Action for RunCommand {
-    fn plan(&self, _: &Manifest, _: &Context) -> Vec<Step> {
+    fn plan(&self, _: &Manifest, _: &Contexts) -> Vec<Step> {
         use crate::atoms::command::Exec;
 
         vec![Step {
@@ -29,7 +38,7 @@ impl Action for RunCommand {
                 command: self.command.clone(),
                 arguments: self.args.clone(),
                 privileged: self.sudo,
-                working_dir: self.dir.clone(),
+                working_dir: Some(self.dir.clone()),
                 ..Default::default()
             }),
             initializers: vec![],
