@@ -1,18 +1,17 @@
-use crate::actions::Action;
 use crate::atoms::directory::Create as DirectoryCreateAtom;
 use crate::manifests::Manifest;
 use crate::steps::Step;
+use crate::{actions::Action, contexts::Contexts};
 use serde::{Deserialize, Serialize};
 use std::path::PathBuf;
-use tera::Context;
 
-#[derive(Clone, Debug, PartialEq, Serialize, Deserialize)]
+#[derive(Clone, Debug, Default, PartialEq, Serialize, Deserialize)]
 pub struct DirectoryCreate {
     pub path: String,
 }
 
 impl Action for DirectoryCreate {
-    fn plan(&self, _: &Manifest, _context: &Context) -> Vec<Step> {
+    fn plan(&self, _: &Manifest, _context: &Contexts) -> Vec<Step> {
         vec![Step {
             atom: Box::new(DirectoryCreateAtom {
                 path: PathBuf::from(&self.path),
@@ -43,7 +42,7 @@ mod tests {
 
         match manifest.actions.pop() {
             Some(Actions::DirectoryCreate(action)) => {
-                assert_eq!("/some-directory", action.path);
+                assert_eq!("/some-directory", action.action.path);
             }
             _ => {
                 panic!("DirectoryCopy didn't deserialize to the correct type");
