@@ -35,7 +35,7 @@ actions:
             ],
         )],
     )
-    .create_in(&path.clone())
+    .create_in(&path)
     .expect("should have create test directories");
 
     let assert = cd(path).run("comtrya directory/copy/main.yaml --dry-run --no-color");
